@@ -8,21 +8,32 @@ mod result;
 pub use result::Hm305pError;
 mod voltage;
 
+/// Get the instantaneous current consumption, in mA
 pub fn get_current_ma() -> Result<u16, Hm305pError> {
     message::send_and_receive(Request::Read(Action::CurrentmA))
 }
 
+/// Get the instantaneous voltage, in mV
+/// # Accuracy
+/// 10mV
 pub fn get_voltage_mv() -> Result<u16, Hm305pError> {
     message::send_and_receive(Request::Read(Action::VoltagemV))
 }
 
-pub fn set_current(current_ma: u16) -> Result<(), Hm305pError> {
+/// Set the current limit, in mA
+pub fn set_current_ma(current_ma: u16) -> Result<(), Hm305pError> {
     let _ = message::send_and_receive(Request::Write((Action::CurrentmA, current_ma)))?;
 
     Ok(())
 }
 
-pub fn set_voltage(voltage_mv: u16) -> Result<(), Hm305pError> {
+/// Set the voltage, in mV
+/// # Accuracy
+/// 10mV, rounded down to the nearest 10mV
+/// # Note
+/// The driver reports success before completing the task, and can take a few seconds to
+/// complete the task.
+pub fn set_voltage_mv(voltage_mv: u16) -> Result<(), Hm305pError> {
     let _ = message::send_and_receive(Request::Write((Action::VoltagemV, voltage_mv)))?;
 
     Ok(())
